@@ -3,14 +3,19 @@
 Ratio planning and scheduling in Python.
 """
 
-__version__ = "0.2.0"
+__version__ = "0.3.0"
 
 # flake8: noqa
 from .classes import (
     Component,
+    ContinuousDistribution,
     Distribution,
     Distributions,
+    Horizon,
     Maintenance,
+    Project,
+    Schedule,
+    ScheduledTask,
     System,
     Task,
     WeibullDistribution,
